.. module:: pulsar

.. _event-handling:

=======================
Events
=======================

Event handling is implemented via the :class:`EventHandler` mixin.

.. _one-time-event:

One time event
=====================


.. _many-times-event:

Many times event
=====================


.. _global-events:

Gloabl Events
=====================

.. automodule:: pulsar.utils.events